@@ -38,13 +38,17 @@ namespace CEC
   class CANCommandHandler : public CCECCommandHandler
   {
   public:
-    CANCommandHandler(CCECBusDevice *busDevice);
+    CANCommandHandler(CCECBusDevice *busDevice,
+                      int32_t iTransmitTimeout = CEC_DEFAULT_TRANSMIT_TIMEOUT,
+                      int32_t iTransmitWait = CEC_DEFAULT_TRANSMIT_WAIT,
+                      int8_t iTransmitRetries = CEC_DEFAULT_TRANSMIT_RETRIES,
+                      int64_t iActiveSourcePending = 0);
     virtual ~CANCommandHandler(void) {};
 
-    bool HandleCommand(const cec_command &command);
+    int HandleVendorRemoteButtonDown(const cec_command &command);
+    int HandleVendorRemoteButtonUp(const cec_command &command);
 
   protected:
-    bool HandleVendorRemoteButtonDown(const cec_command &command);
     bool PowerOn(const cec_logical_address iInitiator, const cec_logical_address iDestination);
   };
 };
